@@ -57,7 +57,7 @@ class PyTryFi(object):
             petString = petString + f"{p}"
         return f"TryFi Instance - {instString}\n Pets in Home:\n {petString}\n Bases In Home:\n {baseString}"
         
-    #refresh pet details
+    #refresh pet details for all pets
     def updatePets(self):
         petListJSON = query.getPetList(self._session)
         updatedPets = []
@@ -85,18 +85,13 @@ class PyTryFi(object):
                 break
             count = count + 1
 
-    def updatePetLocation(self, petId):
-        p = self.getPet(petId)
-        pLocJSON = query.getCurrentPetLocation(self._session,petId)
-        p.setCurrentLocation(pLocJSON)
-        self.updatePetObject(p)
-
+    # return the pet object based on petId
     def getPet(self, petId):
         for p in self.pets:
             if petId == p.petId:
                 return p
         LOGGER.error(f"Cannot find Pet: {petId}")
-        return
+        return None
     
     #refresh base details
     def updateBases(self):
@@ -108,6 +103,18 @@ class PyTryFi(object):
             updatedBases.append(b)
         self._bases = updatedBases
 
+    # return the pet object based on petId
+    def getBase(self, baseId):
+        for b in self.bases:
+            if baseId == b.baseId:
+                return b
+        LOGGER.error(f"Cannot find Base: {baseId}")
+        return None
+
+    def update(self):
+        self.updateBases()
+        self.updatePets()
+
     @property
     def currentUser(self):
         return self._currentUser
@@ -120,19 +127,20 @@ class PyTryFi(object):
     @property
     def username(self):
         return self._username
-    
+    @property
+    def session(self):
+        return self._session
     @property
     def cookies(self):
         return self._cookies
-
     @property
     def userID(self):
         return self._userID
-    
     @property
     def session(self):
         return self._session
 
+    # login to the api and get a session
     def login(self):
         url = API_HOST_URL_BASE + API_LOGIN
         params={
@@ -141,8 +149,12 @@ class PyTryFi(object):
             }
         
         LOGGER.debug(f"Logging into TryFi")
-        
-        response = self._session.post(url, data=params)
+        try:
+            response = self._session.post(url, data=params)
+            response.raise_for_status()
+        except requests.RequestException as e:
+            LOGGER.error(f"Cannot login, error: ({e})")
+            raise requests.RequestException(e)
         error = None
         try:
             error = response.json()['error']
@@ -151,6 +163,7 @@ class PyTryFi(object):
         if error or not response.ok:
             errorMsg = error['message']
             LOGGER.error(f"Cannot login, response: ({response.status_code}): {errorMsg} ")
+            raise Exception("TryFiLoginError")
         #storing cookies but don't need them. Handled by session mgmt
         self._cookies = response.cookies
         #store unique userId from login for future use
